Clock

Struct Clock 

pub struct Clock {
    target_dt: Duration,
    real_time: Duration,
    game_time: Duration,
    last_tick: Instant,
    last_work: Instant,
    tick: u64,
    average_dt: f64,
    average_busy: f64,
    average_variance: f64,
    last_real_dt: f64,
    last_game_dt: f64,
}
A type for maintaining consistent tick/frame pacing.

Fields

target_dt: Duration

This is the dt that the Clock tries to archive with each call of tick.

real_time: Duration

The amount of real time that has passed on the clock

game_time: Duration

The amount of game time that has passed on the clock

last_tick: Instant

The last time the clock was ticked

last_work: Instant

The last time we started performing work

tick: u64

The number of ticks that have elapsed so far

average_dt: f64

The average time between ticks, seconds

average_busy: f64

The average amount of time within each tick in which we’re busy (i.e: not sleeping)

average_variance: f64

The average amount of variance between ticks

last_real_dt: f64

The time that passed between the last tick, and the tick before it

last_game_dt: f64

The dt to be used for the next game tick, in game time.

Implementations

Source

impl Clock

pub fn new(target_dt: Duration) -> Self

pub fn set_target_dt(&mut self, target_dt: Duration)

pub fn stats(&self) -> ClockStats

pub fn real_dt(&self) -> Duration

pub fn game_dt(&self) -> Duration

pub fn tick(&mut self)