pub struct ClockStats {
pub average_busy_dt: Duration,
pub average_tps: f64,
pub average_variance: Duration,
}Fields
average_busy_dt: DurationA weighted average of the recent ‘busy period’ (i.e: time spent doing work rather than sleeping) per tick.
average_tps: f64A weighted average of the recent number of ticks per second.
average_variance: DurationA weighted average of the variance of the clock relative to the average TPS.