pub struct Clock {
target_dt: Duration,
real_time: Duration,
game_time: Duration,
last_tick: Instant,
last_work: Instant,
tick: u64,
average_dt: f64,
average_busy: f64,
average_variance: f64,
last_real_dt: f64,
last_game_dt: f64,
}Expand description
A type for maintaining consistent tick/frame pacing.
Fields
target_dt: DurationThis is the dt that the Clock tries to archive with each call of tick.
real_time: DurationThe amount of real time that has passed on the clock
game_time: DurationThe amount of game time that has passed on the clock
last_tick: InstantThe last time the clock was ticked
last_work: InstantThe last time we started performing work
tick: u64The number of ticks that have elapsed so far
average_dt: f64The average time between ticks, seconds
average_busy: f64The average amount of time within each tick in which we’re busy (i.e: not sleeping)
average_variance: f64The average amount of variance between ticks
last_real_dt: f64The time that passed between the last tick, and the tick before it
last_game_dt: f64The dt to be used for the next game tick, in game time.
Implementations